import asyncio
from datetime import timedelta
from typing import Coroutine

__author__ = "Noah Hummel"
__version__ = "v0.1.3"

def schedule_with_timeout(coro: Coroutine, t: timedelta) -> asyncio.Task:
    """Schedule a Coroutine to run concurrently, cancels after a timeout.

    Args:
        coro: The coroutine to schedule.
        t: The timeout.

    Returns:
        The handle of the scheduled task, may be used to await or cancel the
        coroutine.
    """
    task = asyncio.create_task(coro)

    async def _timeout():
        await asyncio.sleep(t.seconds)
        task.cancel()

    _ = asyncio.create_task(_timeout())
    return task



__author__ = "Noah Hummel"

from setuptools import setup
from codecs import open
from os import path
from src import __version__

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()



setup(
    name='asyncio-helper',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version=__version__,

    description='Library of helper functions for asyncio',
    long_description=long_description,

    # The project's main homepage.
    # url='https://github.com/pypa/sampleproject',

    # Author details
    author='strangedev',
    author_email='strangedev@posteo.net',

    url="https://github.com/strangedev/asyncio-helper",
    download_url=f"https://github.com/strangedev/asyncio-helper/tarball/{__version__}",

    # Choose your license
    license='Apache 2.0',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        'Operating System :: POSIX',
        'Operating System :: MacOS',
        'Operating System :: Unix',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3 :: Only',
    ],

    # What does your project relate to?
    keywords='asyncio helper',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    # packages=find_packages(exclude=['contrib', 'docs', 'tests']),

    packages=['asyncio_helper'],
    package_dir={'asyncio_helper': 'src'},
    package_data={'asyncio_helper': ['Version']},

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    #   py_modules=["my_module"],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=[]
)
